import React, { useMemo } from "react";
import PropTypes from "prop-types";
import { useTranslation } from "react-i18next";
import { Card, CardHeader, CardContent } from "@material-ui/core";
import PageTitle from "../../../../components/common/PageTitle";
import UserProfileCardContent from "./UserProfileCardContent";

const UserProfileComponent = ({ userData }) => {
  const { t } = useTranslation();

  const userLoginDate = useMemo(
    () =>
      t("DATE_FORMAT", {
        date: { value: userData.createdAt, format: "DD-MM-YYYY HH:mm:ss" }
      }),
    [t, userData.createdAt]
  );

  const userDescription = t("User.Profile.Description", {
    userName: `${userData.firstName} ${userData.lastName}`,
    loginDate: userLoginDate
  });

  return (
    <>
      <PageTitle
        text={t("User.Profile.Hello", { userName: userData.firstName })}
      />
      <Card>
        <CardHeader title={userData.userName} subheader={userDescription} />
        <CardContent>
          <UserProfileCardContent userData={userData} />
        </CardContent>
      </Card>
    </>
  );
};

UserProfileComponent.propTypes = {
  userData: PropTypes.object.isRequired
};

export default UserProfileComponent;
